You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nifi.apache.org by mc...@apache.org on 2015/07/02 22:48:03 UTC

[07/10] incubator-nifi git commit: NIFI-694: - Fixing bug when clearing bulletins from the reporting task table. - Allowed ENABLING state to trigger transition to next step of the enable/disable request.

NIFI-694:
- Fixing bug when clearing bulletins from the reporting task table.
- Allowed ENABLING state to trigger transition to next step of the enable/disable request.

Project: http://git-wip-us.apache.org/repos/asf/incubator-nifi/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-nifi/commit/4fd1e949
Tree: http://git-wip-us.apache.org/repos/asf/incubator-nifi/tree/4fd1e949
Diff: http://git-wip-us.apache.org/repos/asf/incubator-nifi/diff/4fd1e949

Branch: refs/heads/develop
Commit: 4fd1e9494e41bea198dabedacee16ed018a3a7b7
Parents: e7c0461
Author: Matt Gilman <ma...@gmail.com>
Authored: Wed Jul 1 14:25:12 2015 -0400
Committer: Matt Gilman <ma...@gmail.com>
Committed: Wed Jul 1 14:25:12 2015 -0400

----------------------------------------------------------------------
 .../src/main/webapp/js/nf/canvas/nf-controller-service.js      | 6 +++---
 .../nifi-web-ui/src/main/webapp/js/nf/canvas/nf-settings.js    | 2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/4fd1e949/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-controller-service.js
----------------------------------------------------------------------
diff --git a/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-settings.js b/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-settings.js
index 3715110..476f34b 100644
--- a/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-settings.js
+++ b/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-settings.js
@@ -1741,7 +1741,7 @@ nf.Settings = (function () {
                 // if there are no bulletins clear all
                 var reportingTasks = reportingTasksData.getItems();
                 $.each(reportingTasks, function(_, reportingTask) {
-                    controllerServicesData.updateItem(reportingTask.id, $.extend(reportingTask, {
+                    reportingTasksData.updateItem(reportingTask.id, $.extend(reportingTask, {
                         bulletins: []
                     }));
                 });
diff --git a/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-controller-service.js b/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-controller-service.js
index efcf9fb..078064a 100644
--- a/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-controller-service.js
+++ b/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-controller-service.js
@@ -591,9 +591,9 @@ nf.ControllerService = (function () {
                         }
                     }
                     
                     // the condition is met once the service is ENABLED/DISABLED
                     if (enabled) {
-                        return service.state === 'ENABLED';
+                        return service.state === 'ENABLING' || service.state === 'ENABLED';
                     } else {
                         return service.state === 'DISABLED';
                     }
@@ -828,7 +828,7 @@ nf.ControllerService = (function () {
             var notEnabled = false;
             $.each(referencingComponents, function(_, referencingComponent) {
                 if (referencingComponent.referenceType === 'ControllerService') {
-                    if (referencingComponent.state !== 'ENABLED') {
+                    if (referencingComponent.state !== 'ENABLING' && referencingComponent.state !== 'ENABLED') {
                         notEnabled = true;
                     } 
                         

http://git-wip-us.apache.org/repos/asf/incubator-nifi/blob/4fd1e949/nifi/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-ui/src/main/webapp/js/nf/canvas/nf-settings.js
----------------------------------------------------------------------
@@ -591,9 +591,9 @@ nf.ControllerService = (function () {
                     }
                     
-                    // the condition is met once the service is ENABLED/DISABLED
+                    // the condition is met once the service is (ENABLING or ENABLED)/DISABLED
                     if (enabled) {